@@ -104,10 +104,10 @@ class TestResources(unittest.TestCase):
         self.url = URL
         self.redmine = Redmine(self.url)
         self.response = mock.Mock(status_code=200)
-        patcher_get = mock.patch('redmine.packages.requests.get', return_value=self.response)
-        patcher_post = mock.patch('redmine.packages.requests.post', return_value=self.response)
-        patcher_put = mock.patch('redmine.packages.requests.put', return_value=self.response)
-        patcher_delete = mock.patch('redmine.packages.requests.delete', return_value=self.response)
+        patcher_get = mock.patch('redmine.requests.get', return_value=self.response)
+        patcher_post = mock.patch('redmine.requests.post', return_value=self.response)
+        patcher_put = mock.patch('redmine.requests.put', return_value=self.response)
+        patcher_delete = mock.patch('redmine.requests.delete', return_value=self.response)
         patcher_get.start()
         patcher_post.start()
         patcher_put.start()
